==> spartaqube-0.1.25.tar.gz: spartaqube-0.1.25/spartaqube/manage.py <==
"""Django's command-line utility for administrative tasks."""
import os
import sys
import re
import json


def sparta_a7b0c49b90(argv):
    """
    Parses the port number from the command-line arguments passed to the runserver command.Returns the port as an integer if found, otherwise defaults to 8000."""
    default_port = 8000
    port = default_port
    if 'runserver' in argv:
        runserver_index = argv.index('runserver')
        if len(argv) > runserver_index + 1:
            address_port = argv[runserver_index + 1]
            if address_port.isdigit():
                port = int(address_port)
            else:
                match = re.search(':(\\d+)$', address_port)
                if match:
                    port = int(match.group(1))
    return port


def sparta_4ba7fe08c4():
    """Run administrative tasks."""
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'spartaqube_app.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and available on your PYTHONPATH environment variable? Did you forget to activate a virtual environment?"
            ) from exc
    django_port = sparta_a7b0c49b90(sys.argv)
    app_data_dict = {'default_port': django_port}
    current_path = os.path.dirname(__file__)
    with open(os.path.join(current_path, 'api/app_data_asgi.json'), 'w'
        ) as json_file:
        json.dump(app_data_dict, json_file)
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    sparta_4ba7fe08c4()

#END OF QUBE

==> spartaqube-0.1.26.tar.gz: spartaqube-0.1.26/spartaqube/manage.py <==
"""Django's command-line utility for administrative tasks."""
import os
import sys
import re
import json


def sparta_4973ea601c(argv):
    """
    Parses the port number from the command-line arguments passed to the runserver command.Returns the port as an integer if found, otherwise defaults to 8000."""
    default_port = 8000
    port = default_port
    if 'runserver' in argv:
        runserver_index = argv.index('runserver')
        if len(argv) > runserver_index + 1:
            address_port = argv[runserver_index + 1]
            if address_port.isdigit():
                port = int(address_port)
            else:
                match = re.search(':(\\d+)$', address_port)
                if match:
                    port = int(match.group(1))
    return port


def sparta_fbbdcce0f6():
    """Run administrative tasks."""
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'spartaqube_app.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and available on your PYTHONPATH environment variable? Did you forget to activate a virtual environment?"
            ) from exc
    django_port = sparta_4973ea601c(sys.argv)
    app_data_dict = {'default_port': django_port}
    current_path = os.path.dirname(__file__)
    api_path = os.path.join(current_path, 'api')
    with open(os.path.join(api_path, 'app_data_asgi.json'), 'w') as json_file:
        json.dump(app_data_dict, json_file)
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    sparta_fbbdcce0f6()

#END OF QUBE
